Developer API Reference
=======================


PyMAD-NG Low Level API (Able to be run independently of madp_object)
--------------------------------------------------------------------

.. automodule:: pymadng.madp_pymad
   :members:
   :undoc-members:
   :show-inheritance:
   

PyMAD-NG Reference Layer for Object Communication
-------------------------------------------------

.. automodule:: pymadng.madp_classes
   :members:
   :undoc-members:
   :show-inheritance:


Helper Functions for Communicating Strings to MAD-NG
----------------------------------------------------

.. automodule:: pymadng.madp_strings
   :members:
   :undoc-members:
   :show-inheritance:

Special Last Object Handler
---------------------------

.. automodule:: pymadng.madp_last
   :members:
   :undoc-members:
   :show-inheritance:
